@@ -124,7 +124,16 @@ class DomainProps:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DomainProps.__init__)
+            def stub(
+                *,
+                zone: typing.Union[builtins.str, aws_cdk.aws_route53.IHostedZone],
+                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+                enable_ipv6: typing.Optional[builtins.bool] = None,
+                region: typing.Optional[builtins.str] = None,
+                subdomain: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
             check_type(argname="argument certificate", value=certificate, expected_type=type_hints["certificate"])
             check_type(argname="argument enable_ipv6", value=enable_ipv6, expected_type=type_hints["enable_ipv6"])
@@ -419,7 +428,9 @@ class _IDomainProxy:
             domain.addTarget(new targets.CloudFrontTarget(distribution))
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(IDomain.add_target)
+            def stub(alias: aws_cdk.aws_route53.IAliasRecordTarget) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
         return typing.cast(None, jsii.invoke(self, "addTarget", [alias]))
 
@@ -464,7 +475,18 @@ class Domain(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Domain.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                zone: typing.Union[builtins.str, aws_cdk.aws_route53.IHostedZone],
+                certificate: typing.Optional[aws_cdk.aws_certificatemanager.ICertificate] = None,
+                enable_ipv6: typing.Optional[builtins.bool] = None,
+                region: typing.Optional[builtins.str] = None,
+                subdomain: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DomainProps(
@@ -493,7 +515,9 @@ class Domain(
             domain.addTarget(new targets.CloudFrontTarget(distribution))
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(Domain.add_target)
+            def stub(alias: aws_cdk.aws_route53.IAliasRecordTarget) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument alias", value=alias, expected_type=type_hints["alias"])
         return typing.cast(None, jsii.invoke(self, "addTarget", [alias]))
 
